DocumentField class

Document field definition

Constructors

DocumentField({String? example, required String label, required String paramname, dynamic valuelist})
DocumentField.fromJson(Map<String, dynamic> json)
factory

Properties

example String?
final
hashCode int
The hash code for this object.
no setterinherited
label String
final
paramname String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
valuelist → dynamic
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited