DocumentInfo class
New document info interface for search API
Constructors
-
DocumentInfo({required String description, required String doctype, required String logo, required List<
DocumentField> requiredParameters}) -
DocumentInfo.fromJson(Map<
String, dynamic> json) -
factory
Properties
- description → String
-
final
- doctype → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- logo → String
-
final
-
requiredParameters
→ List<
DocumentField> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited