GenerateDigiUrlParams class

Parameters for generating DigiLocker URL

Constructors

GenerateDigiUrlParams({required String clientToken, required String redirectUrl, required String companyName, String? documents = 'aadhaar,pan', String? panName, String? panNo, List<Map<String, dynamic>>? otherDocuments})

Properties

clientToken String
final
companyName String
final
documents String?
final
hashCode int
The hash code for this object.
no setterinherited
otherDocuments List<Map<String, dynamic>>?
final
panName String?
final
panNo String?
final
redirectUrl String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited