GenerateDigiUrlResponse class

Response for generate DigiLocker URL API

Constructors

GenerateDigiUrlResponse({required int code, required String msg, required String status, required bool success, required String url})
GenerateDigiUrlResponse.fromJson(Map<String, dynamic> json)
factory

Properties

code int
final
hashCode int
The hash code for this object.
no setterinherited
msg String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String
final
success bool
final
url String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited