GetAccessTokenParams class

Meon DigiLocker SDK Models Contains all the data models used in the SDK Parameters for getting access token

Constructors

GetAccessTokenParams({required String companyName, required String secretToken})

Properties

companyName String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secretToken String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited