GetListOfIssuersInDetailParams class

Parameters for getting list of issuers

Constructors

GetListOfIssuersInDetailParams({required String clientToken, required String state, int? page = 1, bool? allData = false, String? search = ''})

Properties

allData bool?
final
clientToken String
final
hashCode int
The hash code for this object.
no setterinherited
page int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
final
state String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited