SendEntireDataResponse class

Response for send entire data API

Constructors

SendEntireDataResponse({required int code, required SendEntireDataResponseData data, required String msg, required String status, required bool success})
SendEntireDataResponse.fromJson(Map<String, dynamic> json)
factory

Properties

code int
final
data SendEntireDataResponseData
final
hashCode int
The hash code for this object.
no setterinherited
msg String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String
final
success bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited