GetListOfIssuersInDetailResponse class
Response for list of issuers API
Constructors
-
GetListOfIssuersInDetailResponse({required int count, required int currentPage, required int perPage, required List<
IssuerDetail> results, required int totalPages}) -
GetListOfIssuersInDetailResponse.fromJson(Map<
String, dynamic> json) -
factory
Properties
- count → int
-
final
- currentPage → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- perPage → int
-
final
-
results
→ List<
IssuerDetail> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalPages → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited